#ifndef _ABOUT_H__
#define _ABOUT_H__ 1

void about_show(Evas_Object *win, Evas_Object *base, Evas_Object *term,
                  void (*donecb) (void *data), void *donedata);

#endif
